diff --git a/res/res_pjsip_pubsub.c b/res/res_pjsip_pubsub.c
index 8f400b5b68..4df52f7d73 100644
--- a/res/res_pjsip_pubsub.c
+++ b/res/res_pjsip_pubsub.c
@@ -820,8 +820,12 @@ static struct ast_sip_pubsub_body_generator *subscription_get_generator_from_rda
 	const struct ast_sip_subscription_handler *handler)
 {
 	pjsip_accept_hdr *accept_header = (pjsip_accept_hdr *) &rdata->msg_info.msg->hdr;
+	pjsip_user_agent_hdr *user_agent_header;
+	static const pj_str_t USER_AGENT = { "User-Agent", 10 };
+	char *user_agent = NULL;
 	char accept[AST_SIP_MAX_ACCEPT][64];
 	size_t num_accept_headers = 0;
+	size_t alloc_size = 0;
 
 	while ((accept_header = pjsip_msg_find_hdr(rdata->msg_info.msg, PJSIP_H_ACCEPT, accept_header->next)) &&
 		(num_accept_headers < AST_SIP_MAX_ACCEPT)) {
@@ -843,6 +847,17 @@ static struct ast_sip_pubsub_body_generator *subscription_get_generator_from_rda
 		num_accept_headers = 1;
 	}
 
+	user_agent_header = pjsip_msg_find_hdr_by_name(rdata->msg_info.msg, &USER_AGENT, NULL);
+	if (user_agent_header) {
+		alloc_size = pj_strlen(&user_agent_header->hvalue) + 1;
+		user_agent = ast_alloca(alloc_size);
+		ast_copy_pj_str(user_agent, &user_agent_header->hvalue, alloc_size);
+
+		if (strstr(user_agent,"Cisco"))
+			ast_copy_string(accept[0], "application/pidf+xml", sizeof(accept[0]));
+	}
+
+
 	return find_body_generator(accept, num_accept_headers, handler->body_type);
 }
 
